.. _overview:

Momoko
======

An asynchronous Psycopg2_ wrapper for Tornado_.

Momoko makes use of the asynchronous support in Psycopg2, Tornado's IOLoop
to provide asynchronous queries in callback and blocking style.
Downloads can be found at PyPi_ and the lastest source code at Github_.

.. _Tornado: http://www.tornadoweb.org/
.. _Psycopg2: http://initd.org/psycopg/
.. _PyPi: http://pypi.python.org/pypi/Momoko
.. _Github: https://github.com/FSX/momoko

.. toctree::
   :maxdepth: 1

   news
   installation
   examples
   api

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

